// FieldChek.js
//
// SUMMARY
//
// This is a set of JavaScript functions for validating input on 
// an HTML form.  Functions are provided to validate:
//
//      - U.S. and international phone/fax numbers
//      - U.S. ZIP codes (5 or 9 digit postal codes)
//      - U.S. Postal Codes (2 letter abbreviations for names of states)
//      - U.S. Social Security Numbers (abbreviated as SSNs)
//      - email addresses
//	- dates (entry of year, month, and day and validity of combined date)
//	- credit card numbers
//
// Supporting utility functions validate that:
//
//      - characters are Letter, Digit, or LetterOrDigit
//      - strings are a Signed, Positive, Negative, Nonpositive, or
//        Nonnegative integer
//      - strings are a Float or a SignedFloat
//      - strings are Alphabetic, Alphanumeric, or Whitespace
//      - strings contain an integer within a specified range
//
// Functions are also provided to interactively check the
// above kinds of data and prompt the user if they have
// been entered incorrectly.
//
// Other utility functions are provided to:
//
// 	- remove from a string characters which are/are not 
//	  in a "bag" of selected characters	
// 	- reformat a string, adding delimiter characters
//	- strip whitespace/leading whitespace from a string
//      - reformat U.S. phone numbers, ZIP codes, and Social
//        Security numbers
//
//
// Many of the below functions take an optional parameter eok (for "emptyOK")
// which determines whether the empty string will return true or false.
// Default behavior is controlled by global variable defaultEmptyOK.
//
// BASIC DATA VALIDATION FUNCTIONS:
//
// isWhitespace (s)                    Check whether string s is empty or whitespace.
// isLetter (c)                        Check whether character c is an English letter 
// isDigit (c)                         Check whether character c is a digit 
// isLetterOrDigit (c)                 Check whether character c is a letter or digit.
// isNumeric (s [,eok])                True if all characters in string s are numbers.
// isSignedInteger (s [,eok])          True if all characters in string s are numbers; leading + or - allowed.
// isPositiveInteger (s [,eok])        True if string s is an integer > 0.
// isNonnegativeInteger (s [,eok])     True if string s is an integer >= 0.
// isNegativeInteger (s [,eok])        True if s is an integer < 0.
// isNonpositiveInteger (s [,eok])     True if s is an integer <= 0.
// isFloat (s [,eok])                  True if string s is an unsigned floating point (real) number. (Integers also OK.)
// isSignedFloat (s [,eok])            True if string s is a floating point number; leading + or - allowed. (Integers also OK.)
// isAlphabetic (s [,eok])             True if string s is English letters 
// isAlphanumeric (s [,eok])           True if string s is English letters and numbers only.
// isSSN (s [,eok])                    True if string s is a valid U.S. Social Security Number.
// isTaxID (s [,eok])                  True if string s is a valid U.S. Tax ID.
// isPhone (s [,eok])          True if string s is a valid U.S. Phone Number. 
// isZIPCode (s [,eok])                True if string s is a valid U.S. ZIP code.
// isYear (s [,eok])                   True if string s is a valid Year number.
// isIntegerInRange (s, a, b [,eok])   True if string s is an integer between a and b, inclusive.
// isMonth (s [,eok])                  True if string s is a valid month between 1 and 12.
// isDay (s [,eok])                    True if string s is a valid day between 1 and 31.
// daysInFebruary (year)               Returns number of days in February of that year.
// isDate (year, month, day)           True if string arguments form a valid date.


// FUNCTIONS TO REFORMAT DATA:
//
// stripCharsInBag (s, bag)		Removes all characters in string bag from string s.
// stripCharsNotInBag (s, bag)		Removes all characters NOT in string bag from string s.
// stripWhitespace (s)			Removes all whitespace characters from s.
// stripInitialWhitespace (s)		Removes initial (leading) whitespace characters from s.
// reformat (TARGETSTRING, STRING,	Function for inserting formatting characters or
//   INTEGER, STRING, INTEGER ... )       delimiters into TARGETSTRING.                                       
// reformatZip (ZIPString)		If 9 digits, inserts separator hyphen.
// reformatSSN (SSN)			Reformats as 123-45-6789.
// reformatPhone (USPhone)		Reformats as 123-456-789.
// reformatTaxId (TaxID)		REformats as 12-3456789.
// reformatDate (Date)			REformats as 12/34/5678.
// Format (s)				Formatting the value according the parameter "s". "s" could be
//					SSN, TAXID, PHONE, ZIP and DATE.
// FormatSSN()				
// FormatTaxID()
// FormatPhone()
// FormatZip()
// FormatDate()

// FUNCTIONS TO PROMPT USER:
//
// prompt (s)                          Display prompt string s in status bar.
// promptEntry (s)                     Display data entry prompt string s in status bar.
// warnEmpty (theField, s)             Notify user that required field theField is empty.
// warnInvalid (theField, s)           Notify user that contents of field theField are invalid.


// FUNCTIONS TO INTERACTIVELY CHECK FIELD CONTENTS:
//
// checkString (theField, s [,eok])    Check that theField.value is not empty or all whitespace.
// checkZip (theField [,eok])      Check that theField.value is a valid ZIP code.
// checkPhone (theField [,eok])      Check that theField.value is a valid US Phone.
// checkSSN (theField [,eok])          Check that theField.value is a valid SSN.
// checkTaxID (theField [,eok])          Check that theField.value is a valid Tax ID.
// checkDate (yearField, monthField, dayField, labelString, OKtoOmitDay)
//                                     Check that field values form a valid date.
// checkInteger (theField [,eok])	Check that theField.value is integer.
// checkFloat (theField [,eok])		Check that theField.value is float (decimal point allowed).
// checkPercentage (theField [,eok])	Check that the Field.value is a valid percentage value.
// checkMinLength (thField, len [,eok]) 	Check that the length of the Field.value is at least len.
// checkMandatory (theField [,eok])	Check that the Field.value is not empty

// VARIABLE DECLARATIONS
var digits = "0123456789";
var lowercaseLetters = "abcdefghijklmnopqrstuvwxyz"
var uppercaseLetters = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"

// whitespace characters
var whitespace = " \t\n\r";

// decimal point character differs by language and culture
var decimalPointDelimiter = "."

// non-digit characters which are allowed in phone numbers
var phoneNumberDelimiters = "()-/ ";

// characters which are allowed in US phone numbers
var validUSPhoneChars = digits + phoneNumberDelimiters;

// characters which are allowed in international phone numbers
// (a leading + is OK)
var validWorldPhoneChars = digits + phoneNumberDelimiters + "+";

// non-digit characters which are allowed in 
// Social Security Numbers
var SSNDelimiters = "-";

// Date
var DateDelimiters = "/";

// characters which are allowed in Social Security Numbers
var validSSNChars = digits + SSNDelimiters;

// U.S. Social Security Numbers have 9 digits.
// They are formatted as 123-45-6789.
var digitsInSocialSecurityNumber = 9;

// U.S. Tax ID have 9 digits.
// They are formatted as 12-3456789.
var digitsInTaxID = 9;

// U.S. phone numbers have 10 digits.
// They are formatted as 123-456-7890.
var digitsInUSPhoneNumber = 10;

// non-digit characters which are allowed in ZIP Codes
var ZIPCodeDelimiters = "-";

// our preferred delimiter for reformatting ZIP Codes
var ZIPCodeDelimeter = "-"

// characters which are allowed in Social Security Numbers
var validZIPCodeChars = digits + ZIPCodeDelimiters

// U.S. ZIP codes have 5 or 9 digits.
// They are formatted as 12345 or 12345-6789.
var digitsInZIPCode1 = 5
var digitsInZIPCode2 = 9

// non-digit characters which are allowed in credit card numbers
var creditCardDelimiters = " "


// CONSTANT STRING DECLARATIONS
// (grouped for ease of translation and localization)
// m is an abbreviation for "missing"
var mPrefix = "You did not enter a value into the "
var mSuffix = " field. This is a required field. Please enter it now."

// s is an abbreviation for "string"
var sUSLastName = "Last Name"
var sUSFirstName = "First Name"
var sWorldLastName = "Family Name"
var sWorldFirstName = "Given Name"
var sTitle = "Title"
var sCompanyName = "Company Name"
var sUSAddress = "Street Address"
var sWorldAddress = "Address"
var sCity = "City"
var sStateCode = "State Code"
var sWorldState = "State, Province, or Prefecture"
var sCountry = "Country"
var sZIPCode = "ZIP Code"
var sWorldPostalCode = "Postal Code"
var sPhone = "Phone Number"
var sFax = "Fax Number"
var sDateOfBirth = "Date of Birth"
var sSSN = "Social Security Number"
var sOtherInfo = "Other Information"

// i is an abbreviation for "invalid"
var iZIPCode = "This field must be a 5 or 9 digit U.S. ZIP Code (like 94043). Please reenter it now."
var iUSPhone = "This field must be a 10 digit U.S. phone number (like 415-555-1212). Please reenter it now."
var iSSN = "This field must be a 9 digit U.S. social security number (like 123-45-6789). Please reenter it now."
var iTaxID = "This field must be a 9 digit U.S. Tax ID (like 123456789). Please reenter it now."
var iDay = "This field must be a 2 digit day number between 01 and 31.  Please reenter it now."
var iMonth = "This field must be a 2 digit month number between 01 and 12.  Please reenter it now."
var iYear = "This field must be a 4 digit number.  Please reenter it now."
var iHour = "This field must be a 2 digit hour number between 00 and 23.  Please reenter it now."
var iMinute = "This field must be a 2 digit minute number between 00 and 59.  Please reenter it now."
var iSecond = "This field must be a 2 digit second number between 00 and 59.  Please reenter it now."
var iDatePrefix = "The Day, Month, and Year for "
var iDateSuffix = " do not form a valid date.  Please reenter them now."
//var iInteger = "Invalid integer number. Please reenter it now."  //original
var iInteger = "Please enter number only." //modify by charlene
var iFloat = "This field does not allow alphabetic characters. Please reenter it now."
var iPercentage = "Invalid percentage number. Please reenter it now."

// p is an abbreviation for "prompt"
var pEntryPrompt = "Please enter a "
var pZIPCode = "5 or 9 digit U.S. ZIP Code (like 94043)."
var pUSPhone = "10 digit U.S. phone number (like 415-555-1212)."
var pSSN = "9 digit U.S. social security number (like 123-45-6789)."
var pDay = "day number between 1 and 31."
var pMonth = "month number between 1 and 12."
var pYear = "2 or 4 digit year number."

// Global variable defaultEmptyOK defines default return value 
// for many functions when they are passed the empty string. 
// By default, they will return defaultEmptyOK.
//
// defaultEmptyOK is false, which means that by default, 
// these functions will do "strict" validation.  Function
// isNumeric, for example, will only return true if it is
// passed a string containing an integer; if it is passed
// the empty string, it will return false.
//
// You can change this default behavior globally (for all 
// functions which use defaultEmptyOK) by changing the value
// of defaultEmptyOK.
//
// Most of these functions have an optional argument emptyOK
// which allows you to override the default behavior for 
// the duration of a function call.
//
// This functionality is useful because it is possible to
// say "if the user puts anything in this field, it must
// be an integer (or a phone number, or a string, etc.), 
// but it's OK to leave the field empty too."
// This is the case for fields which are optional but which
// must have a certain kind of content if filled in.

var defaultEmptyOK = true

// Attempting to make this library run on Navigator 2.0,
// so I'm supplying this array creation routine as per
// JavaScript 1.0 documentation.  If you're using 
// Navigator 3.0 or later, you don't need to do this;
// you can use the Array constructor instead.

function makeArray(n) {
//*** BUG: If I put this line in, I get two error messages:
//(1) Window.length can't be set by assignment
//(2) daysInMonth has no property indexed by 4
//If I leave it out, the code works fine.
//   this.length = n;
   for (var i = 1; i <= n; i++) {
      this[i] = 0
   } 
   return this
}

var daysInMonth = makeArray(12);
daysInMonth[1] = 31;
daysInMonth[2] = 29;   // must programmatically check this
daysInMonth[3] = 31;
daysInMonth[4] = 30;
daysInMonth[5] = 31;
daysInMonth[6] = 30;
daysInMonth[7] = 31;
daysInMonth[8] = 31;
daysInMonth[9] = 30;
daysInMonth[10] = 31;
daysInMonth[11] = 30;
daysInMonth[12] = 31;

// Check whether string s is empty.
function isEmpty(s)
{   return ((s == null) || (s.length == 0))
}

// Returns true if string s is empty or 
// whitespace characters only.
function isWhitespace (s)
{   var i;
    // Is s empty?
    if (isEmpty(s)) return true;

    // Search through string's characters one by one
    // until we find a non-whitespace character.
    // When we do, return false; if we don't, return true.

    for (i = 0; i < s.length; i++)
    {   
        // Check that current character isn't whitespace.
        var c = s.charAt(i);

        if (whitespace.indexOf(c) == -1) return false;
    }
    // All characters are whitespace.
    return true;
}


// Removes all characters which appear in string bag from string s.
function stripCharsInBag (s, bag)
{   var i;
    var returnString = "";

    // Search through string's characters one by one.
    // If character is not in bag, append to returnString.

    for (i = 0; i < s.length; i++)
    {   
        // Check that current character isn't whitespace.
        var c = s.charAt(i);
        if (bag.indexOf(c) == -1) returnString += c;
    }
    return returnString;
}

// Removes all characters which do NOT appear in string bag 
// from string s.
function stripCharsNotInBag (s, bag)
{   var i;
    var returnString = "";

    // Search through string's characters one by one.
    // If character is in bag, append to returnString.

    for (i = 0; i < s.length; i++)
    {   
        // Check that current character isn't whitespace.
        var c = s.charAt(i);
        if (bag.indexOf(c) != -1) returnString += c;
    }
    return returnString;
}

// Removes all whitespace characters from s.
// Global variable whitespace (see above)
// defines which characters are considered whitespace.
function stripWhitespace (s)
{   return stripCharsInBag (s, whitespace)
}

// WORKAROUND FUNCTION FOR NAVIGATOR 2.0.2 COMPATIBILITY.
//
// The below function *should* be unnecessary.  In general,
// avoid using it.  Use the standard method indexOf instead.
//
// However, because of an apparent bug in indexOf on 
// Navigator 2.0.2, the below loop does not work as the
// body of stripInitialWhitespace:
//
// while ((i < s.length) && (whitespace.indexOf(s.charAt(i)) != -1))
//   i++;
//
// ... so we provide this workaround function charInString
// instead.
//
// charInString (CHARACTER c, STRING s)
//
// Returns true if single character c (actually a string)
// is contained within string s.
function charInString (c, s)
{   for (i = 0; i < s.length; i++)
    {   if (s.charAt(i) == c) return true;
    }
    return false
}


// Removes initial (leading) whitespace characters from s.
// Global variable whitespace (see above)
// defines which characters are considered whitespace.
function stripInitialWhitespace (s)
{   var i = 0;

    while ((i < s.length) && charInString (s.charAt(i), whitespace))
       i++;
    
    return s.substring (i, s.length);
}

// Returns true if character c is an English letter 
// (A .. Z, a..z).
//
// NOTE: Need i18n version to support European characters.
// This could be tricky due to different character
// sets and orderings for various languages and platforms.
function isLetter (c)
{   return ( ((c >= "a") && (c <= "z")) || ((c >= "A") && (c <= "Z")) )
}

// Returns true if character c is a digit 
// (0 .. 9).
function isDigit (c)
{   return ((c >= "0") && (c <= "9"))
}

// Returns true if character c is a letter or digit.
function isLetterOrDigit (c)
{   return (isLetter(c) || isDigit(c))
}

// isNumeric (STRING s [, BOOLEAN emptyOK])
// 
// Returns true if all characters in string s are numbers.
//
// Accepts non-signed integers only. Does not accept floating 
// point, exponential notation, etc.
//
// We don't use parseInt because that would accept a string
// with trailing non-numeric characters.
//
// By default, returns defaultEmptyOK if s is empty.
// There is an optional second argument called emptyOK.
// emptyOK is used to override for a single function call
//      the default behavior which is specified globally by
//      defaultEmptyOK.
// If emptyOK is false (or any value other than true), 
//      the function will return false if s is empty.
// If emptyOK is true, the function will return true if s is empty.
//
// EXAMPLE FUNCTION CALL:     RESULT:
// isNumeric ("5")            true 
// isNumeric ("")             defaultEmptyOK
// isNumeric ("-5")           false
// isNumeric ("", true)       true
// isNumeric ("", false)      false
// isNumeric ("5", false)     true
function isNumeric (s)
{   var i;
    if (isEmpty(s)) 
       if (isNumeric.arguments.length == 1) return defaultEmptyOK;
       else return (isNumeric.arguments[1] == true);

    // Search through string's characters one by one
    // until we find a non-numeric character.
    // When we do, return false; if we don't, return true.

    for (i = 0; i < s.length; i++)
    {   
        // Check that current character is number.
        var c = s.charAt(i);

        if (!isDigit(c)) return false;
    }

    // All characters are numbers.
    return true;
}


// isSignedInteger (STRING s [, BOOLEAN emptyOK])
// 
// Returns true if all characters are numbers; 
// first character is allowed to be + or - as well.
//
// Does not accept floating point, exponential notation, etc.
//
// We don't use parseInt because that would accept a string
// with trailing non-numeric characters.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
//
// EXAMPLE FUNCTION CALL:          RESULT:
// isSignedInteger ("5")           true 
// isSignedInteger ("")            defaultEmptyOK
// isSignedInteger ("-5")          true
// isSignedInteger ("+5")          true
// isSignedInteger ("", false)     false
// isSignedInteger ("", true)      true
function isSignedInteger (s)
{   if (isEmpty(s)) 
       if (isSignedInteger.arguments.length == 1) return defaultEmptyOK;
       else return (isSignedInteger.arguments[1] == true);

    else {
        var startPos = 0;
        var secondArg = defaultEmptyOK;

        if (isSignedInteger.arguments.length > 1)
            secondArg = isSignedInteger.arguments[1];

        // skip leading + or -
        if ( (s.charAt(0) == "-") || (s.charAt(0) == "+") )
           startPos = 1;    
        return (isNumeric(s.substring(startPos, s.length), secondArg))
    }
}


// isPositiveInteger (STRING s [, BOOLEAN emptyOK])
// 
// Returns true if string s is an integer > 0.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isPositiveInteger (s)
{   var secondArg = defaultEmptyOK;

    if (isPositiveInteger.arguments.length > 1)
        secondArg = isPositiveInteger.arguments[1];

    // The next line is a bit byzantine.  What it means is:
    // a) s must be a signed integer, AND
    // b) one of the following must be true:
    //    i)  s is empty and we are supposed to return true for
    //        empty strings
    //    ii) this is a positive, not negative, number

    return (isSignedInteger(s, secondArg)
         && ( (isEmpty(s) && secondArg)  || (parseInt (s) > 0) ) );
}

// isNonnegativeInteger (STRING s [, BOOLEAN emptyOK])
// 
// Returns true if string s is an integer >= 0.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isNonnegativeInteger (s)
{   var secondArg = defaultEmptyOK;

    if (isNonnegativeInteger.arguments.length > 1)
        secondArg = isNonnegativeInteger.arguments[1];

    // The next line is a bit byzantine.  What it means is:
    // a) s must be a signed integer, AND
    // b) one of the following must be true:
    //    i)  s is empty and we are supposed to return true for
    //        empty strings
    //    ii) this is a number >= 0

    return (isSignedInteger(s, secondArg)
         && ( (isEmpty(s) && secondArg)  || (parseInt (s) >= 0) ) );
}


// isNegativeInteger (STRING s [, BOOLEAN emptyOK])
// 
// Returns true if string s is an integer < 0.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isNegativeInteger (s)
{   var secondArg = defaultEmptyOK;

    if (isNegativeInteger.arguments.length > 1)
        secondArg = isNegativeInteger.arguments[1];

    // The next line is a bit byzantine.  What it means is:
    // a) s must be a signed integer, AND
    // b) one of the following must be true:
    //    i)  s is empty and we are supposed to return true for
    //        empty strings
    //    ii) this is a negative, not positive, number

    return (isSignedInteger(s, secondArg)
         && ( (isEmpty(s) && secondArg)  || (parseInt (s) < 0) ) );
}


// isNonpositiveInteger (STRING s [, BOOLEAN emptyOK])
// 
// Returns true if string s is an integer <= 0.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isNonpositiveInteger (s)
{   var secondArg = defaultEmptyOK;

    if (isNonpositiveInteger.arguments.length > 1)
        secondArg = isNonpositiveInteger.arguments[1];

    // The next line is a bit byzantine.  What it means is:
    // a) s must be a signed integer, AND
    // b) one of the following must be true:
    //    i)  s is empty and we are supposed to return true for
    //        empty strings
    //    ii) this is a number <= 0

    return (isSignedInteger(s, secondArg)
         && ( (isEmpty(s) && secondArg)  || (parseInt (s) <= 0) ) );
}


// isFloat (STRING s [, BOOLEAN emptyOK])
// 
// True if string s is an unsigned floating point (real) number. 
//
// Also returns true for unsigned integers. If you wish
// to distinguish between integers and floating point numbers,
// first call isNumeric, then call isFloat.
//
// Does not accept exponential notation.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isFloat (s)
{   var i;
    var seenDecimalPoint = false;

    if (isEmpty(s)) 
       if (isFloat.arguments.length == 1) return defaultEmptyOK;
       else return (isFloat.arguments[1] == true);

    if (s == decimalPointDelimiter) return false;

    // Search through string's characters one by one
    // until we find a non-numeric character.
    // When we do, return false; if we don't, return true.

    for (i = 0; i < s.length; i++)
    {   
        // Check that current character is number.
        var c = s.charAt(i);

        if ((c == decimalPointDelimiter) && !seenDecimalPoint) seenDecimalPoint = true;
        else if (!isDigit(c)) return false;
    }

    // All characters are numbers.
    return true;
}


// isSignedFloat (STRING s [, BOOLEAN emptyOK])
// 
// True if string s is a signed or unsigned floating point 
// (real) number. First character is allowed to be + or -.
//
// Also returns true for unsigned integers. If you wish
// to distinguish between integers and floating point numbers,
// first call isSignedInteger, then call isSignedFloat.
//
// Does not accept exponential notation.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isSignedFloat (s)
{   if (isEmpty(s)) 
       if (isSignedFloat.arguments.length == 1) return defaultEmptyOK;
       else return (isSignedFloat.arguments[1] == true);

    else {
        var startPos = 0;
        var secondArg = defaultEmptyOK;

        if (isSignedFloat.arguments.length > 1)
            secondArg = isSignedFloat.arguments[1];

        // skip leading + or -
        if ( (s.charAt(0) == "-") || (s.charAt(0) == "+") )
           startPos = 1;    
        return (isFloat(s.substring(startPos, s.length), secondArg))
    }
}


// isAlphabetic (STRING s [, BOOLEAN emptyOK])
// 
// Returns true if string s is English letters 
// (A .. Z, a..z) only.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
//
// NOTE: Need i18n version to support European characters.
// This could be tricky due to different character
// sets and orderings for various languages and platforms.
function isAlphabetic (s)
{   var i;

    if (isEmpty(s)) 
       if (isAlphabetic.arguments.length == 1) return defaultEmptyOK;
       else return (isAlphabetic.arguments[1] == true);

    // Search through string's characters one by one
    // until we find a non-alphabetic character.
    // When we do, return false; if we don't, return true.

    for (i = 0; i < s.length; i++)
    {   
        // Check that current character is letter.
        var c = s.charAt(i);

        if (!isLetter(c))
        return false;
    }

    // All characters are letters.
    return true;
}


// isAlphanumeric (STRING s [, BOOLEAN emptyOK])
// 
// Returns true if string s is English letters 
// (A .. Z, a..z) and numbers only.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
//
// NOTE: Need i18n version to support European characters.
// This could be tricky due to different character
// sets and orderings for various languages and platforms.
function isAlphanumeric (s)
{   var i;

    if (isEmpty(s)) 
       if (isAlphanumeric.arguments.length == 1) return defaultEmptyOK;
       else return (isAlphanumeric.arguments[1] == true);

    // Search through string's characters one by one
    // until we find a non-alphanumeric character.
    // When we do, return false; if we don't, return true.

    for (i = 0; i < s.length; i++)
    {   
        // Check that current character is number or letter.
        var c = s.charAt(i);

        if (! (isLetter(c) || isDigit(c) ) )
        return false;
    }

    // All characters are numbers or letters.
    return true;
}


// reformat (TARGETSTRING, STRING, INTEGER, STRING, INTEGER ... )       
//
// Handy function for arbitrarily inserting formatting characters
// or delimiters of various kinds within TARGETSTRING.
//
// reformat takes one named argument, a string s, and any number
// of other arguments.  The other arguments must be integers or
// strings.  These other arguments specify how string s is to be
// reformatted and how and where other strings are to be inserted
// into it.
//
// reformat processes the other arguments in order one by one.
// * If the argument is an integer, reformat appends that number 
//   of sequential characters from s to the resultString.
// * If the argument is a string, reformat appends the string
//   to the resultString.
//
// NOTE: The first argument after TARGETSTRING must be a string.
// (It can be empty.)  The second argument must be an integer.
// Thereafter, integers and strings must alternate.  This is to
// provide backward compatibility to Navigator 2.0.2 JavaScript
// by avoiding use of the typeof operator.
//
// It is the caller's responsibility to make sure that we do not
// try to copy more characters from s than s.length.
//
// EXAMPLES:
//
// * To reformat a 10-digit U.S. phone number from "1234567890"
//   to "(123) 456-7890" make this function call:
//   reformat("1234567890", "(", 3, ") ", 3, "-", 4)
//
// * To reformat a 9-digit U.S. Social Security number from
//   "123456789" to "123-45-6789" make this function call:
//   reformat("123456789", "", 3, "-", 2, "-", 4)
//
// HINT:
//
// If you have a string which is already delimited in one way
// (example: a phone number delimited with spaces as "123 456 7890")
// and you want to delimit it in another way using function reformat,
// call function stripCharsNotInBag to remove the unwanted 
// characters, THEN call function reformat to delimit as desired.
//
// EXAMPLE:
//
// reformat (stripCharsNotInBag ("123 456 7890", digits),
//           "(", 3, ") ", 3, "-", 4)
function reformat (s)
{   var arg;
    var sPos = 0;
    var resultString = "";

    for (var i = 1; i < reformat.arguments.length; i++) {
       arg = reformat.arguments[i];
       if (i % 2 == 1) resultString += arg;
       else {
           resultString += s.substring(sPos, sPos + arg);
           sPos += arg;
       }
    }
    return resultString;
}


// isSSN (STRING s [, BOOLEAN emptyOK])
// 
// isSSN returns true if string s is a valid U.S. Social
// Security Number.  Must be 9 digits.
//
// NOTE: Strip out any delimiters (spaces, hyphens, etc.)
// from string s before calling this function.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isSSN (s)
{   if (isEmpty(s)) 
       if (isSSN.arguments.length == 1) return defaultEmptyOK;
       else return (isSSN.arguments[1] == true);
    return (isNumeric(s) && s.length == digitsInSocialSecurityNumber)
}

// isTaxID (STRING s [, BOOLEAN emptyOK])
// 
// isTaxID returns true if string s is a valid U.S. Tax ID. Must be in 9 digits.
//
// NOTE: Strip out any delimiters (spaces, hyphens, etc.)
// from string s before calling this function.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isTaxID (s)
{   if (isEmpty(s)) 
       if (isTaxID.arguments.length == 1) return defaultEmptyOK;
       else return (isTaxID.arguments[1] == true);
    return (isNumeric(s) && s.length == digitsInTaxID)
}


// isPhone (STRING s [, BOOLEAN emptyOK])
// 
// isPhone returns true if string s is a valid U.S. Phone
// Number.  Must be 10 digits.
//
// NOTE: Strip out any delimiters (spaces, hyphens, parentheses, etc.)
// from string s before calling this function.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isPhone (s)
{   if (isEmpty(s)) 
       if (isPhone.arguments.length == 1) return defaultEmptyOK;
       else return (isPhone.arguments[1] == true);
    return (isNumeric(s) && s.length == digitsInUSPhoneNumber)
}


// isZIPCode (STRING s [, BOOLEAN emptyOK])
// 
// isZIPCode returns true if string s is a valid 
// U.S. ZIP code.  Must be 5 or 9 digits only.
//
// NOTE: Strip out any delimiters (spaces, hyphens, etc.)
// from string s before calling this function.  
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isZIPCode (s)
{  if (isEmpty(s)) 
       if (isZIPCode.arguments.length == 1) return defaultEmptyOK;
       else return (isZIPCode.arguments[1] == true);
   return (isNumeric(s) && 
            ((s.length == digitsInZIPCode1) ||
             (s.length == digitsInZIPCode2)))
}


// isYear (STRING s [, BOOLEAN emptyOK])
// 
// isYear returns true if string s is a valid 
// Year number.  Must be 4 digits only.
// 
// For Year 2000 compliance, you are advised
// to use 4-digit year numbers everywhere.
//
// And yes, this function is not Year 10000 compliant, but 
// because I am giving you 8003 years of advance notice,
// I don't feel very guilty about this ...
//
// For B.C. compliance, write your own function. ;->
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isYear (s)
{   if (isEmpty(s)) 
       if (isYear.arguments.length == 1) return defaultEmptyOK;
       else return (isYear.arguments[1] == true);
    if (!isNonnegativeInteger(s)) return false;
    return (s.length == 4);
}


// isIntegerInRange (STRING s, INTEGER a, INTEGER b [, BOOLEAN emptyOK])
// 
// isIntegerInRange returns true if string s is an integer 
// within the range of integer arguments a and b, inclusive.
// 
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isIntegerInRange (s, a, b){
   if (isEmpty(s)) 
       if (isIntegerInRange.arguments.length == 1) return defaultEmptyOK;
       else return (isIntegerInRange.arguments[1] == true);

    // Catch non-integer strings to avoid creating a NaN below,
    // which isn't available on JavaScript 1.0 for Windows.
    if (!isNumeric(s, false)) return false;

    // Now, explicitly change the type to integer via parseInt
    // so that the comparison code below will work both on 
    // JavaScript 1.2 (which typechecks in equality comparisons)
    // and JavaScript 1.1 and before (which doesn't).
    var num = s.valueOf();
    return ((num >= a) && (num <= b));
}


// isMonth (STRING s [, BOOLEAN emptyOK])
// 
// isMonth returns true if string s is a valid 
// month number between 1 and 12.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function isMonth (s){
   if (isEmpty(s)) 
       if (isMonth.arguments.length == 1) return defaultEmptyOK;
       else return (isMonth.arguments[1] == true);
    return isIntegerInRange(s, 1, 12);
}


// isDay (STRING s [, BOOLEAN emptyOK])
// 
// isDay returns true if string s is a valid 
// day number between 1 and 31.
// 
// For explanation of optional argument emptyOK,
// see comments of function isInteger.
function isDay (s)
{   if (isEmpty(s)) 
       if (isDay.arguments.length == 1) return defaultEmptyOK;
       else return (isDay.arguments[1] == true);   
    return isIntegerInRange (s, 1, 31);
}


function isHour (s)
{   if (isEmpty(s)) 
       if (isHour.arguments.length == 1) return defaultEmptyOK;
       else return (isHour.arguments[1] == true);   
    return isIntegerInRange (s, 0, 23);
}
function isMinute (s)
{   if (isEmpty(s)) 
       if (isMinute.arguments.length == 1) return defaultEmptyOK;
       else return (isMinute.arguments[1] == true);   
    return isIntegerInRange (s, 0, 59);
}
function isSec(s)
{   if (isEmpty(s)) 
       if (isSec.arguments.length == 1) return defaultEmptyOK;
       else return (isSec.arguments[1] == true);   
    return isIntegerInRange (s, 0, 59);
}// daysInFebruary (INTEGER year)
// 
// Given integer argument year,
// returns number of days in February of that year.
function daysInFebruary (year)
{   // February has 29 days in any year evenly divisible by four,
    // EXCEPT for centurial years which are not also divisible by 400.
    return (  ((year % 4 == 0) && ( (!(year % 100 == 0)) || (year % 400 == 0) ) ) ? 29 : 28 );
}


// isDate (STRING year, STRING month, STRING day)
//
// isDate returns true if string arguments year, month, and day 
// form a valid date.
// 
function isDate (year, month, day)
{   // catch invalid years (not 2- or 4-digit) and invalid months and days.
    if (! (isYear(year, false) && isMonth(month, false) && isDay(day, false))) return false;

    // Explicitly change type to integer to make code work in both
    // JavaScript 1.1 and JavaScript 1.2.
    var intYear = parseInt(year);
    var intMonth = parseInt(month);
    var intDay = parseInt(day);

    // catch invalid days, except for February
    if (intDay > daysInMonth[intMonth]) return false; 

    if ((intMonth == 2) && (intDay > daysInFebruary(intYear))) return false;

    return true;
}


/* FUNCTIONS TO NOTIFY USER OF INPUT REQUIREMENTS OR MISTAKES. */

// Display prompt string s in status bar.
function prompt (s)
{   window.status = s
}


// Display data entry prompt string s in status bar.
function promptEntry (s)
{   window.status = pEntryPrompt + s
}


// Notify user that required field theField is empty.
// String s describes expected contents of theField.value.
// Put focus in theField and return false.
function warnEmpty (theField, s)
{   theField.focus()
    alert(mPrefix + s + mSuffix)
    return false
}


// Notify user that contents of field theField are invalid.
// String s describes expected contents of theField.value.
// Put select theField, pu focus in it, and return false.
function warnInvalid (theField, s)
{   
    alert(s);
    theField.focus();
 //   theField.select();
    return false;
}


/* FUNCTIONS TO INTERACTIVELY CHECK VARIOUS FIELDS. */

// checkString (TEXTFIELD theField, STRING s, [, BOOLEAN emptyOK==false])
//
// Check that string theField.value is not all whitespace.
//
// For explanation of optional argument emptyOK,
// see comments of function isInteger.
function checkString (theField, s, emptyOK)
{   // Next line is needed on NN3 to avoid "undefined is not a number" error
    // in equality comparison below.
    if (checkString.arguments.length == 2) emptyOK = defaultEmptyOK;
    if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    if (isWhitespace(theField.value)) 
       return warnEmpty (theField, s);
    else return true;
}


// takes ZIPString, a string of 5 or 9 digits;
// if 9 digits, inserts separator hyphen
function reformatZip (ZIPString)
{   if (ZIPString.length == 5) return ZIPString;
    else return (reformat (ZIPString, "", 5, "-", 4));
}

// takes Phone, a string of 10 digits
// and reformats as 123-456-789

function reformatPhone (USPhone)
{   return (reformat (USPhone, "", 3, "-", 3, "-", 4))
}

// takes SSN, a string of 9 digits
// and reformats as 123-45-6789

function reformatSSN (SSN)
{   return (reformat (SSN, "", 3, "-", 2, "-", 4))
}

// takes Tax ID, a string of 9 digits
// and reformats as 12-3456789

function reformatTaxID (TaxID)
{   return (reformat (TaxID, "", 2, "-", 7))
}

// takes Date, a string of 8 digits
// and reformats as 12/34/5678

function reformatDate (Date)
{   return (reformat (Date, "", 2, "/", 2, "/", 4))
}

// checkZip (TEXTFIELD theField [, BOOLEAN emptyOK==false])
//
// Check that string theField.value is a valid ZIP code.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function checkZip (theField, emptyOK)
{   if (checkZip.arguments.length == 1) emptyOK = defaultEmptyOK;
    if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    else
    { var normalizedZIP = stripCharsInBag(theField.value, ZIPCodeDelimiters)
      if (!isZIPCode(normalizedZIP, false)) 
         return warnInvalid (theField, iZIPCode);
      else 
      {  // if you don't want to insert a hyphen, comment next line out
         theField.value = reformatZip(normalizedZIP)
         return true;
      }
    }
}


// checkPhone (TEXTFIELD theField [, BOOLEAN emptyOK==false])
//
// Check that string theField.value is a valid US Phone.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function checkPhone (theField, emptyOK)
{   if (checkPhone.arguments.length == 1) emptyOK = defaultEmptyOK;
    if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    else
    {  var normalizedPhone = stripCharsInBag(theField.value, phoneNumberDelimiters)
       if (!isPhone(normalizedPhone, false)) 
          return warnInvalid (theField, iUSPhone);
       else
       {
       	  theField.value = reformatPhone(normalizedPhone)
          return true;
       }
       
    }
}


// Check that string theField.value is a valid SSN.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function checkSSN (theField, emptyOK)
{   if (checkSSN.arguments.length == 1) emptyOK = defaultEmptyOK;
    if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    else
    {  var normalizedSSN = stripCharsInBag(theField.value, SSNDelimiters)
       if (!isSSN(normalizedSSN, false))
          return warnInvalid (theField, iSSN);
       else
       {
          theField.value = reformatSSN(normalizedSSN)
          return true;
       }
    }
}

// Check that string theField.value is a valid Tax ID.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function checkTaxID (theField, emptyOK)
{   if (checkTaxID.arguments.length == 1) emptyOK = defaultEmptyOK;
    if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    else
    {  var normalizedTaxID = stripCharsInBag(theField.value, SSNDelimiters)
       if (!isTaxID(normalizedTaxID, false)) 
          return warnInvalid (theField, iTaxID);
       else
       {  
			//we do not use FormatTaxID to format taxID field		  
		  //theField.value = reformatTaxID(normalizedTaxID)

		  return true;
       }
    }
}

// Check that string theField.value is integer.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function checkInteger (theField, emptyOK)
{   if (checkInteger.arguments.length == 1) emptyOK = defaultEmptyOK;
    if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    else
    {  var normalizedInteger = stripCharsInBag(theField.value, whitespace)
       if (!isNumeric(normalizedInteger, false)) 
          return warnInvalid (theField, iInteger);
    }
}

// Check that string theField.value is float (decimal allowed).
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function checkFloat (theField, emptyOK)
{   if (checkFloat.arguments.length == 1) emptyOK = defaultEmptyOK;
    if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    else
    {  var normalizedFloat = stripCharsInBag(theField.value, whitespace)
       if (!isSignedFloat(normalizedFloat, false)) 
          return warnInvalid (theField, iFloat);
    }
} 

// Check that string theField.value is a valid percentage value.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function checkPercentage (theField, emptyOK)
{   if (checkPercentage.arguments.length == 1) emptyOK = defaultEmptyOK;
    if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    else
    {	var normalizedNum = stripCharsInBag(theField.value, whitespace);
    	if (!isSignedFloat(normalizedNum, false)) 
    		return warnInvalid (theField, iPercentage);
    	if (theField.value >100)
    		return warnInvalid (theField, iPercentage);
    }
}

// Check that the length of theField.value is at least the number of len.
//
// For explanation of optional argument emptyOK,
// see comments of function isNumeric.
function checkMinLength (theField, len, emptyOK)
{   var fieldLen = theField.value;   
    if (fieldLen.length == 0) emptyOK = defaultEmptyOK;
    if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    else
    {	
    	if (fieldLen.length < len) {
    		if(theField.name == "YEAR")
    			alert('Year must be ' + len + ' digits. Please reenter it now.');
    		else
			alert('The minimum length of ' + theField.name + ' field is ' + len + '. Please reenter it now.');
		
		theField.focus();
		theField.select();
    		return false;
    	}
    }
}

// checkDate (yearField, monthField, dayField, STRING labelString [, OKtoOmitDay==false])
//
// Check that yearField.value, monthField.value, and dayField.value 
// form a valid date.
//
// If they don't, labelString (the name of the date, like "Birth Date")
// is displayed to tell the user which date field is invalid.
//
// If it is OK for the day field to be empty, set optional argument
// OKtoOmitDay to true.  It defaults to false.
function checkDate (theField, OKtoOmitDay)
{   // Next line is needed on NN3 to avoid "undefined is not a number" error
    // in equality comparison below.
    var emptyOK
	if (checkDate.arguments.length == 1) emptyOK = defaultEmptyOK;
    else emptyOK=OKtoOmitDay;
	if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    else
    {
    	if(theField.value.length != 10)
	{
	   alert("Invalid Date format. The format is mm/dd/yyyy. Please reenter it now.");
	   theField.focus();
	   theField.select();
	}
	else
    	{
    	   var month = theField.value.substring(0, 2);
	   var day = theField.value.substring(3,5);
    	   var year = theField.value.substring(6,10);
 
    	   if (!isMonth(month)) return warnInvalid (theField, iMonth);
    	   //if ( (OKtoOmitDay == true) && isEmpty(dayField.value) ) return true;
    	   if (!isDay(day)) 
    	      return warnInvalid (theField, iDay);
    	   if (!isYear(year)) return warnInvalid (theField, iYear);
    	   if (isDate (year, month, day))
    	      return true;
    	   theField.focus();
    	   theField.select();
    	   alert (iDatePrefix + iDateSuffix);
    	   return false;
    	}
    }
}

//Hong added to validate the Date & Time field
function checkDateTime (theField, OKtoOmitDay)
{   // Next line is needed on NN3 to avoid "undefined is not a number" error
    // in equality comparison below.
    if (checkDateTime.arguments.length == 1) emptyOK = defaultEmptyOK;
    if ((emptyOK == true) && (isEmpty(theField.value))) return true;
    else
    {
    	if(theField.value.length != 19)
	{
	   alert("Invalid Date Time format. The format is mm/dd/yyyy hh:mi:ss. Please reenter it now.");
	   theField.focus();
	   theField.select();
	}
	else
    	{
    		var month = theField.value.substring(0, 2);
			var day = theField.value.substring(3,5);
    		var year = theField.value.substring(6,10);
    		var hour = theField.value.substring(11,13); 			
    		var minute = theField.value.substring(14,16); 			 
    		var sec = theField.value.substring(17,19); 			
    		if (!isMonth(month)) return warnInvalid (theField, iMonth);
    		//if ( (OKtoOmitDay == true) && isEmpty(dayField.value) ) return true;
    		if (!isDay(day)) 
    		   return warnInvalid (theField, iDay);
    		if (!isYear(year)) return warnInvalid (theField, iYear);
     		if (!isHour(hour)) return warnInvalid (theField, iHour); 
    		if (!isMinute(minute)) return warnInvalid (theField, iMinute);  
    		if (!isSec(sec)) return warnInvalid (theField, iSecond);   
 
     		if (isDate (year, month, day))
    		  return true;
    		theField.focus();
    		theField.select();
    		alert (iDatePrefix + iDateSuffix);
    		return false;
    	}
    }
}

// Check that string theField.value is empty or not.
//
function checkMandatory (theField, emptyOK)
{   if (isEmpty(theField.value)) return warnEmpty (theField, theField.name);
}


function FormatSSN() {
	Format('SSN');
}
function FormatTaxID(){
	Format('TAXID');
}
function FormatPhone(){
	Format('PHONE');
}
function FormatZip(){
	Format('ZIP');
}
function FormatDate(){
	Format('DATE');
}

function FormatDateTime(){
	Format('DATETIME');
}

function Format(type) {
	var keychar = event.keyCode;
	if(type == "SSN"){
		if ((event.srcElement.value.length == 3) || (event.srcElement.value.length == 6)) {
			if (unescape(keychar) != 8) {
				event.srcElement.value += SSNDelimiters;
			}
		}
	} else if(type == "TAXID"){
		if ((event.srcElement.value.length == 2)) {
			if (unescape(keychar) != 8) {
				event.srcElement.value += SSNDelimiters;
			}
		}
	} else if(type == "ZIP"){
		if ((event.srcElement.value.length == 5)) {
			if (unescape(keychar) != 8) {
				event.srcElement.value += SSNDelimiters;
			}
		}
	}else if(type == "PHONE"){
		if ((event.srcElement.value.length == 3) || (event.srcElement.value.length == 7)) {
			if (unescape(keychar) != 8) {
				event.srcElement.value += SSNDelimiters;
			}
		}
	}else if(type == "DATE"){
		if ((event.srcElement.value.length == 2) || (event.srcElement.value.length == 5)) {
			if (unescape(keychar) != 8) {
				event.srcElement.value += DateDelimiters;
			}
		}
		
//Hong added to format the Date & Time field
	}else if(type == "DATETIME"){
		if ((event.srcElement.value.length == 2) || (event.srcElement.value.length == 5)) {
			if (unescape(keychar) != 8) {
				event.srcElement.value += DateDelimiters;
			}
		}
		if (event.srcElement.value.length == 10) {
			if (unescape(keychar) != 8) {
				event.srcElement.value +=" ";
			}
		}
		if ((event.srcElement.value.length == 13) || (event.srcElement.value.length == 16)) {
			if (unescape(keychar) != 8) {
				event.srcElement.value += ":";
			}
		}
	}
}
//Hong added to check length of text area
function checkTextArea(textField,length){
		if(textField.value.length>parseInt(length)){
			alert("This field should be no more than "+length +" characters!");
	   		textField.focus();
	   		textField.select();
	}	
}

function moneyFormat(moneyField,totalLength){
		if (((window.event.keyCode<48) || (57 < window.event.keyCode))&&window.event.keyCode!=110&&window.event.keyCode!=190) {
			if ((window.event.keyCode !=37) &&
			 (window.event.keyCode !=46) &&
			 (window.event.keyCode !=39) &&
			 (window.event.keyCode !=16) &&
			 (window.event.keyCode !=3) &&
			 (window.event.keyCode !=9) &&(window.event.keyCode !=8) ) 
			{
				alert("This field does not allow alphabetic characters. Please reenter it now.");     
				moneyField.focus();
    			moneyField.select();
				return false;							
			}
		}

		if(moneyField.value.length==1&&moneyField.value.indexOf("$")==-1) moneyField.value = '$'+moneyField.value;
		else
		{
			var tempstr = unformat(moneyField.value);
	
	
			if(tempstr.length>(totalLength-1)&&tempstr.indexOf(".")==-1){
				alert("Value is too large for this field. Please reenter it now.");     
				moneyField.focus();
    			moneyField.select();
				return false;
			}
			if(tempstr.indexOf(".")!=-1){
				if(tempstr.substr(tempstr.indexOf(".")).length>3){		
					alert("No more than 2 digits after dot. Please reenter it now.");     
					moneyField.focus();
    				moneyField.select();
					return false;
				}							
			}
			var tempstrLength = tempstr.length;
			var formatstr = tempstr;
			if( tempstr.indexOf(".")!=-1) tempstrLength = tempstr.indexOf(".");
			if( tempstrLength>4&&tempstrLength<8) formatstr = tempstr.substr(0,tempstrLength-3)+','+tempstr.substr(tempstrLength-3);
			if( tempstrLength>7&&tempstrLength<11) formatstr = tempstr.substr(0,tempstrLength-6)+','+tempstr.substr(tempstrLength-6,3)+','+tempstr.substr(tempstrLength-3);			
			if( tempstrLength>10&&tempstrLength<14) formatstr =tempstr.substr(0,tempstrLength-9)+','+tempstr.substr(tempstrLength-9,3)+','+tempstr.substr(tempstrLength-6,3)+','+tempstr.substr(tempstrLength-3);						
			moneyField.value = formatstr;
		}
}

function unformat(fieldValue)
{
	var i;
	var tempstr='';
	for(i=0;i<fieldValue.length;i++)
		if(fieldValue.charAt(i)!=',') tempstr += fieldValue.charAt(i);
	return tempstr;
}	

// Check that string theField.value is float and less than fieldValue.
function checkFloatValue (theField, fieldValue)
{
  	if(isEmpty(theField.value)) return true;
   	var normalizedFloat = stripCharsInBag(theField.value, whitespace)
    if (!isSignedFloat(normalizedFloat, false)) 
          return warnInvalid (theField, iFloat);
    else if (theField.value>fieldValue)
          return warnInvalid (theField, "The value of this field can not be more than "+fieldValue);	
	else  return true;	  	
}


// Check that string theField.value is integer and less than thevalue of field.
function checkIntegerValue (theField, field)
{   
    if (isEmpty(theField.value)) return true;
 	var normalizedInteger = stripCharsInBag(theField.value, whitespace)
    if (!isNumeric(normalizedInteger, false)) 
          return warnInvalid (theField, iInteger);
    else if (theField.value > field.value)
          return warnInvalid (theField, "Total Minority Employees can not be greater than Total Employees");	
	else  return true;	  	
}

// Check that string theField.value is integer and less than thevalue of field.
function checkRelation(theField, field)
{   
    if (isEmpty(theField.value)) return true;
	if(!isEmpty(field.value))return true;
	else{
		alert("Bonding amount must be inserted at first");	
		theField.value='';
		field.focus();    
		return false;		
	}
/* 	var normalizedInteger = stripCharsInBag(theField.value, whitespace)
    if (!isNumeric(normalizedInteger, false)) 
          return warnInvalid (theField, iInteger);
    else if (theField.value > field.value)
          return warnInvalid (theField, "Total Minority Employees can not be greater than Total Employees");	
	else  return true;	  	
*/
}

// Check that string theField.value is integer and less than thevalue of field.
function checkFromEndDate (s, fromDate, endDate)
{   
    if(isEmpty(fromDate.value) || isEmpty(endDate.value))
    	return true;
    else{    
    	var fmonth = fromDate.value.substring(0, 2);
    	var fday = fromDate.value.substring(3,5);
    	var fyear = fromDate.value.substring(6,10);
    	var emonth = endDate.value.substring(0, 2);
    	var eday = endDate.value.substring(3,5);
    	var eyear = endDate.value.substring(6,10);
    	if(fyear.valueOf()<eyear.valueOf())return true;
		else{ 
    		if(fyear.valueOf()>eyear.valueOf())   	
    			return warnInvalid(endDate,s + " To Date is earlier than " + s + " From Date. Please reenter.");		
    		if(fyear.valueOf()==eyear.valueOf()){
				if(fmonth.valueOf()<emonth.valueOf())return true; 
				else{
					if(fmonth.valueOf()>emonth.valueOf())
    					return warnInvalid(endDate, s + " To Date is earlier than " + s + " From Date. Please reenter.");
    				if(fmonth.valueOf()==emonth.valueOf()){
    					if(fday.valueOf()>eday.valueOf())
    						return warnInvalid(endDate,s + " To Date is earlier than " + s + " From Date. Please reenter.");
    					else    			
    						return true;
    				}
				}	
    		}	
    	}
	
	}
}


//set the related locked field
function setLock(theField) {
//alert(theField.checked);
	if (theField.checked) {
		document.forms[0].MCC_ID.disabled=false;
		document.forms[0].CONTROLLING_PERCENT.disabled=false;		
		document.forms[0].OWNERSHIP_PERCENT.disabled=false;			
	} else {
	
		document.forms[0].MCC_ID.value='';
		document.forms[0].CONTROLLING_PERCENT.value='';
		document.forms[0].OWNERSHIP_PERCENT.value='';
		document.forms[0].MCC_ID.disabled=true;
		document.forms[0].CONTROLLING_PERCENT.disabled=true;		
		document.forms[0].OWNERSHIP_PERCENT.disabled=true;			
	}

}


function init() {
	if('object'==typeof document.forms[0].ISOWNER){
		if (!(document.forms[0].ISOWNER.checked)) {
			document.forms[0].MCC_ID.disabled=true;
			document.forms[0].CONTROLLING_PERCENT.disabled=true;		
			document.forms[0].OWNERSHIP_PERCENT.disabled=true;			
		}
	}
}

function emailCheck (emailStr) {
/* The following pattern is used to check if the entered e-mail address
   fits the user@domain format.  It also is used to separate the username
   from the domain. */
var emailPat=/^(.+)@(.+)$/
/* The following string represents the pattern for matching all special
   characters.  We don't want to allow special characters in the address. 
   These characters include ( ) < > @ , ; : \ " . [ ]    */
var specialChars="\\(\\)<>@:\\\\\\\"\\.\\[\\]"
/* The following string represents the range of characters allowed in a 
   username or domainname.  It really states which chars aren't allowed. */
var validChars="\[^\\s" + specialChars + "\]"
/* The following pattern applies if the "user" is a quoted string (in
   which case, there are no rules about which characters are allowed
   and which aren't; anything goes).  E.g. "jiminy cricket"@disney.com
   is a legal e-mail address. */
var quotedUser="(\"[^\"]*\")"
/* The following pattern applies for domains that are IP addresses,
   rather than symbolic names.  E.g. joe@[123.124.233.4] is a legal
   e-mail address. NOTE: The square brackets are required. */
var ipDomainPat=/^\[(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})\]$/
/* The following string represents an atom (basically a series of
   non-special characters.) */
var atom=validChars + '+'
/* The following string represents one word in the typical username.
   For example, in john.doe@somewhere.com, john and doe are words.
   Basically, a word is either an atom or quoted string. */
var word="(" + atom + "|" + quotedUser + ")"
// The following pattern describes the structure of the user
var userPat=new RegExp("^" + word + "(\\." + word + ")*$")
/* The following pattern describes the structure of a normal symbolic
   domain, as opposed to ipDomainPat, shown above. */
var domainPat=new RegExp("^" + atom + "(\\." + atom +")*$")


/* Finally, let's start trying to figure out if the supplied address is
   valid. */

/* Begin with the coarse pattern to simply break up user@domain into
   different pieces that are easy to analyze. */
var matchArray=emailStr.match(emailPat)
if (matchArray==null) {
  /* Too many/few @'s or something; basically, this address doesn't
     even fit the general mould of a valid e-mail address. */
	//alert("Email address seems incorrect (check @ and .'s)")
	return false
}
var user=matchArray[1]
var domain=matchArray[2]

// See if "user" is valid 
if (user.match(userPat)==null) {
    // user is not valid
    //alert("The username doesn't seem to be valid.")
    return false
}

/* if the e-mail address is at an IP address (as opposed to a symbolic
   host name) make sure the IP address is valid. */
var IPArray=domain.match(ipDomainPat)
if (IPArray!=null) {
    // this is an IP address
	  for (var i=1;i<=4;i++) {
	    if (IPArray[i]>255) {
	        //alert("Destination IP address is invalid!")
		return false
	    }
    }
    return true
}

// Domain is symbolic name
var domainArray=domain.match(domainPat)
if (domainArray==null) {
	//alert("The domain name doesn't seem to be valid.")
    return false
}

/* domain name seems valid, but now make sure that it ends in a
   three-letter word (like com, edu, gov) or a two-letter word,
   representing country (uk, nl), and that there's a hostname preceding 
   the domain or country. */

/* Now we need to break up the domain to get a count of how many atoms
   it consists of. */
var atomPat=new RegExp(atom,"g")
var domArr=domain.match(atomPat)
var len=domArr.length
if (domArr[domArr.length-1].length<2 || 
    domArr[domArr.length-1].length>3) {
   // the address must end in a two letter or three letter word.
   //alert("The address must end in a three-letter domain, or two letter country.")
   return false
}

// Make sure there's a host name preceding the domain.
if (len<2) {
   var errStr="This address is missing a hostname!"
   //alert(errStr)
   return false
}

// If we've gotten this far, everything's valid!
return true;
}
